EXPORTS
	??1CIMPSConnUiClntFilteredPresEventNotifier@@UAE@XZ @ 1 NONAME ; CIMPSConnUiClntFilteredPresEventNotifier::~CIMPSConnUiClntFilteredPresEventNotifier(void)
	??1CIMPSConnUiConnectionModeNotifier@@UAE@XZ @ 2 NONAME ; CIMPSConnUiConnectionModeNotifier::~CIMPSConnUiConnectionModeNotifier(void)
	??1CIMPSConnUiConnectionSettingsNotifier@@UAE@XZ @ 3 NONAME ; CIMPSConnUiConnectionSettingsNotifier::~CIMPSConnUiConnectionSettingsNotifier(void)
	??1CIMPSConnUiPresEventNotifier@@UAE@XZ @ 4 NONAME ; CIMPSConnUiPresEventNotifier::~CIMPSConnUiPresEventNotifier(void)
	??1CIMPSConnectionUiAgent@@UAE@XZ @ 5 NONAME ; CIMPSConnectionUiAgent::~CIMPSConnectionUiAgent(void)
	??1CIMPSPresenceAAConnection@@UAE@XZ @ 6 NONAME ; CIMPSPresenceAAConnection::~CIMPSPresenceAAConnection(void)
	??1CIMPSPresenceConnectionUi@@UAE@XZ @ 7 NONAME ; CIMPSPresenceConnectionUi::~CIMPSPresenceConnectionUi(void)
	??1CIMPSResourceReader@@UAE@XZ @ 8 NONAME ; CIMPSResourceReader::~CIMPSResourceReader(void)
	?AddObserverL@CIMPSConnUiConnectionModeNotifier@@UAEXPAVMIMPSConnUiConnectionModeObserver@@@Z @ 9 NONAME ; void CIMPSConnUiConnectionModeNotifier::AddObserverL(class MIMPSConnUiConnectionModeObserver *)
	?AddObserverL@CIMPSConnUiConnectionSettingsNotifier@@UAEXPAVMIMPSConnUiConnectionSettingsObserver@@@Z @ 10 NONAME ; void CIMPSConnUiConnectionSettingsNotifier::AddObserverL(class MIMPSConnUiConnectionSettingsObserver *)
	?AddObserverL@CIMPSConnUiPresEventNotifier@@UAEXPAVMIMPSConnUiPresenceEventObserver@@@Z @ 11 NONAME ; void CIMPSConnUiPresEventNotifier::AddObserverL(class MIMPSConnUiPresenceEventObserver *)
	?AppServiceStatusL@CIMPSConnUiPresEventNotifier@@UAEPBVCPEngNWSessionSlotID2@@W4TIMPSConnectionClient@@@Z @ 12 NONAME ; class CPEngNWSessionSlotID2 const * CIMPSConnUiPresEventNotifier::AppServiceStatusL(enum TIMPSConnectionClient)
	?ConnectionModeByCategoryL@CIMPSConnUiConnectionModeNotifier@@UAE?AW4TIMPSConnectionModeEvent@@W42@@Z @ 13 NONAME ; enum TIMPSConnectionModeEvent CIMPSConnUiConnectionModeNotifier::ConnectionModeByCategoryL(enum TIMPSConnectionModeEvent)
	?ConnectionModeL@CIMPSConnUiConnectionModeNotifier@@UAE?AW4TIMPSConnectionModeEvent@@XZ @ 14 NONAME ; enum TIMPSConnectionModeEvent CIMPSConnUiConnectionModeNotifier::ConnectionModeL(void)
	?ConnectionSettingByCategoryL@CIMPSConnUiConnectionSettingsNotifier@@UAE?AW4TIMPSConnectionSettingsEvent@@W42@@Z @ 15 NONAME ; enum TIMPSConnectionSettingsEvent CIMPSConnUiConnectionSettingsNotifier::ConnectionSettingByCategoryL(enum TIMPSConnectionSettingsEvent)
	?CurrentConnectionOperationL@CIMPSPresenceConnectionUi@@QAE?AW4TIMPSConnectionOperation@@AAPAVHBufC16@@@Z @ 16 NONAME ; enum TIMPSConnectionOperation CIMPSPresenceConnectionUi::CurrentConnectionOperationL(class HBufC16 * &)
	?DefaultServerNameL@CIMPSPresenceAAConnection@@QAEPAVHBufC16@@W4TIMPSConnectionClient@@@Z @ 17 NONAME ; class HBufC16 * CIMPSPresenceAAConnection::DefaultServerNameL(enum TIMPSConnectionClient)
	?DisplayDomainSelectionQueryL@CIMPSPresenceConnectionUi@@QAEHAAVTDes16@@PAVCIMPSSAPSettings@@@Z @ 18 NONAME ; int CIMPSPresenceConnectionUi::DisplayDomainSelectionQueryL(class TDes16 &, class CIMPSSAPSettings *)
	?GetActiveNWSessionSlotIDL@CIMPSPresenceAAConnection@@QAEPAVCPEngNWSessionSlotID2@@W4TIMPSConnectionClient@@@Z @ 19 NONAME ; class CPEngNWSessionSlotID2 * CIMPSPresenceAAConnection::GetActiveNWSessionSlotIDL(enum TIMPSConnectionClient)
	?GetActiveNWSessionSlotIDL@CIMPSPresenceConnectionUi@@QAEPAVCPEngNWSessionSlotID2@@W4TIMPSConnectionClient@@@Z @ 20 NONAME ; class CPEngNWSessionSlotID2 * CIMPSPresenceConnectionUi::GetActiveNWSessionSlotIDL(enum TIMPSConnectionClient)
	?GetLoggedInSapL@CIMPSPresenceConnectionUi@@QAEHABVCPEngNWSessionSlotID2@@AAVCIMPSSAPSettings@@@Z @ 21 NONAME ; int CIMPSPresenceConnectionUi::GetLoggedInSapL(class CPEngNWSessionSlotID2 const &, class CIMPSSAPSettings &)
	?HandleApplicationExitL@CIMPSPresenceConnectionUi@@QAEHW4TIMPSConnectionClient@@W4TIMPSExitType@@ABVCPEngNWSessionSlotID2@@PAVMIMPSConnProcessObserver@@@Z @ 22 NONAME ; int CIMPSPresenceConnectionUi::HandleApplicationExitL(enum TIMPSConnectionClient, enum TIMPSExitType, class CPEngNWSessionSlotID2 const &, class MIMPSConnProcessObserver *)
	?HandleSapAccessEventEventL@MIMPSConnProcessObserver@@UAEXABVTDesC16@@0PAVMIMPSConnProcessUi@@@Z @ 23 NONAME ; void MIMPSConnProcessObserver::HandleSapAccessEventEventL(class TDesC16 const &, class TDesC16 const &, class MIMPSConnProcessUi *)
	?IsRoamingWarningRequiredL@CIMPSResourceReader@@QAEHXZ @ 24 NONAME ; int CIMPSResourceReader::IsRoamingWarningRequiredL(void)
	?LoggedInL@CIMPSPresenceAAConnection@@QAEHW4TIMPSConnectionClient@@@Z @ 25 NONAME ; int CIMPSPresenceAAConnection::LoggedInL(enum TIMPSConnectionClient)
	?LoggedInL@CIMPSPresenceConnectionUi@@QAEHW4TIMPSConnectionClient@@@Z @ 26 NONAME ; int CIMPSPresenceConnectionUi::LoggedInL(enum TIMPSConnectionClient)
	?LoginL@CIMPSPresenceAAConnection@@QAEHW4TIMPSConnectionClient@@H@Z @ 27 NONAME ; int CIMPSPresenceAAConnection::LoginL(enum TIMPSConnectionClient, int)
	?LoginL@CIMPSPresenceConnectionUi@@QAEHW4TIMPSConnectionClient@@W4TIMPSLoginType@@AAVCPEngNWSessionSlotID2@@PAVMIMPSConnProcessObserver@@PAVCIMPSSAPSettings@@H@Z @ 28 NONAME ; int CIMPSPresenceConnectionUi::LoginL(enum TIMPSConnectionClient, enum TIMPSLoginType, class CPEngNWSessionSlotID2 &, class MIMPSConnProcessObserver *, class CIMPSSAPSettings *, int)
	?LogoutL@CIMPSPresenceAAConnection@@QAEHW4TIMPSConnectionClient@@H@Z @ 29 NONAME ; int CIMPSPresenceAAConnection::LogoutL(enum TIMPSConnectionClient, int)
	?LogoutL@CIMPSPresenceConnectionUi@@QAEHABVCPEngNWSessionSlotID2@@PAVMIMPSConnProcessObserver@@@Z @ 30 NONAME ; int CIMPSPresenceConnectionUi::LogoutL(class CPEngNWSessionSlotID2 const &, class MIMPSConnProcessObserver *)
	?NewL@CIMPSConnUiClntFilteredPresEventNotifier@@SAPAV1@W4TIMPSConnectionClient@@@Z @ 31 NONAME ; class CIMPSConnUiClntFilteredPresEventNotifier * CIMPSConnUiClntFilteredPresEventNotifier::NewL(enum TIMPSConnectionClient)
	?NewL@CIMPSConnUiConnectionModeNotifier@@SAPAV1@W4TIMPSConnectionClient@@@Z @ 32 NONAME ; class CIMPSConnUiConnectionModeNotifier * CIMPSConnUiConnectionModeNotifier::NewL(enum TIMPSConnectionClient)
	?NewL@CIMPSConnUiConnectionSettingsNotifier@@SAPAV1@W4TIMPSConnectionClient@@@Z @ 33 NONAME ; class CIMPSConnUiConnectionSettingsNotifier * CIMPSConnUiConnectionSettingsNotifier::NewL(enum TIMPSConnectionClient)
	?NewL@CIMPSConnUiPresEventNotifier@@SAPAV1@XZ @ 34 NONAME ; class CIMPSConnUiPresEventNotifier * CIMPSConnUiPresEventNotifier::NewL(void)
	?NewL@CIMPSConnectionUiAgent@@SAPAV1@W4TIMPSConnectionClient@@@Z @ 35 NONAME ; class CIMPSConnectionUiAgent * CIMPSConnectionUiAgent::NewL(enum TIMPSConnectionClient)
	?NewL@CIMPSPresenceAAConnection@@SAPAV1@W4TIMPSConnectionClient@@PAVCIMPSSAPSettingsStore@@@Z @ 36 NONAME ; class CIMPSPresenceAAConnection * CIMPSPresenceAAConnection::NewL(enum TIMPSConnectionClient, class CIMPSSAPSettingsStore *)
	?NewL@CIMPSPresenceConnectionUi@@SAPAV1@W4TIMPSConnectionClient@@PAVCIMPSSAPSettingsStore@@@Z @ 37 NONAME ; class CIMPSPresenceConnectionUi * CIMPSPresenceConnectionUi::NewL(enum TIMPSConnectionClient, class CIMPSSAPSettingsStore *)
	?NewL@CIMPSResourceReader@@SAPAV1@XZ @ 38 NONAME ; class CIMPSResourceReader * CIMPSResourceReader::NewL(void)
	?NewLC@CIMPSConnUiClntFilteredPresEventNotifier@@SAPAV1@W4TIMPSConnectionClient@@@Z @ 39 NONAME ; class CIMPSConnUiClntFilteredPresEventNotifier * CIMPSConnUiClntFilteredPresEventNotifier::NewLC(enum TIMPSConnectionClient)
	?NewLC@CIMPSConnUiConnectionModeNotifier@@SAPAV1@W4TIMPSConnectionClient@@@Z @ 40 NONAME ; class CIMPSConnUiConnectionModeNotifier * CIMPSConnUiConnectionModeNotifier::NewLC(enum TIMPSConnectionClient)
	?NewLC@CIMPSConnUiConnectionSettingsNotifier@@SAPAV1@W4TIMPSConnectionClient@@@Z @ 41 NONAME ; class CIMPSConnUiConnectionSettingsNotifier * CIMPSConnUiConnectionSettingsNotifier::NewLC(enum TIMPSConnectionClient)
	?NewLC@CIMPSConnUiPresEventNotifier@@SAPAV1@XZ @ 42 NONAME ; class CIMPSConnUiPresEventNotifier * CIMPSConnUiPresEventNotifier::NewLC(void)
	?NewLC@CIMPSPresenceAAConnection@@SAPAV1@W4TIMPSConnectionClient@@PAVCIMPSSAPSettingsStore@@@Z @ 43 NONAME ; class CIMPSPresenceAAConnection * CIMPSPresenceAAConnection::NewLC(enum TIMPSConnectionClient, class CIMPSSAPSettingsStore *)
	?NewLC@CIMPSPresenceConnectionUi@@SAPAV1@W4TIMPSConnectionClient@@PAVCIMPSSAPSettingsStore@@@Z @ 44 NONAME ; class CIMPSPresenceConnectionUi * CIMPSPresenceConnectionUi::NewLC(enum TIMPSConnectionClient, class CIMPSSAPSettingsStore *)
	?NewLC@CIMPSResourceReader@@SAPAV1@XZ @ 45 NONAME ; class CIMPSResourceReader * CIMPSResourceReader::NewLC(void)
	?PureServiceStatusL@CIMPSPresenceAAConnection@@QAE?AW4TPEngNWSessionSlotState@@ABVCPEngNWSessionSlotID2@@@Z @ 46 NONAME ; enum TPEngNWSessionSlotState CIMPSPresenceAAConnection::PureServiceStatusL(class CPEngNWSessionSlotID2 const &)
	?PureServiceStatusL@CIMPSPresenceConnectionUi@@QAE?AW4TPEngNWSessionSlotState@@ABVCPEngNWSessionSlotID2@@@Z @ 47 NONAME ; enum TPEngNWSessionSlotState CIMPSPresenceConnectionUi::PureServiceStatusL(class CPEngNWSessionSlotID2 const &)
	?RemoveObserver@CIMPSConnUiConnectionModeNotifier@@UAEHPAVMIMPSConnUiConnectionModeObserver@@@Z @ 48 NONAME ; int CIMPSConnUiConnectionModeNotifier::RemoveObserver(class MIMPSConnUiConnectionModeObserver *)
	?RemoveObserver@CIMPSConnUiConnectionSettingsNotifier@@UAEHPAVMIMPSConnUiConnectionSettingsObserver@@@Z @ 49 NONAME ; int CIMPSConnUiConnectionSettingsNotifier::RemoveObserver(class MIMPSConnUiConnectionSettingsObserver *)
	?RemoveObserver@CIMPSConnUiPresEventNotifier@@UAEHPAVMIMPSConnUiPresenceEventObserver@@@Z @ 50 NONAME ; int CIMPSConnUiPresEventNotifier::RemoveObserver(class MIMPSConnUiPresenceEventObserver *)
	?ReservedObservMethod_1L@MIMPSConnProcessObserver@@UAEHXZ @ 51 NONAME ; int MIMPSConnProcessObserver::ReservedObservMethod_1L(void)
	?ReservedObservMethod_2L@MIMPSConnProcessObserver@@UAEHXZ @ 52 NONAME ; int MIMPSConnProcessObserver::ReservedObservMethod_2L(void)
	?ReservedObservMethod_3L@MIMPSConnProcessObserver@@UAEHXZ @ 53 NONAME ; int MIMPSConnProcessObserver::ReservedObservMethod_3L(void)
	?Reserved_1@@YAXXZ @ 54 NONAME ; void Reserved_1(void)
	?StartL@CIMPSConnUiConnectionModeNotifier@@UAEXXZ @ 55 NONAME ; void CIMPSConnUiConnectionModeNotifier::StartL(void)
	?StartL@CIMPSConnUiConnectionSettingsNotifier@@UAEXXZ @ 56 NONAME ; void CIMPSConnUiConnectionSettingsNotifier::StartL(void)
	?StartL@CIMPSConnUiPresEventNotifier@@UAEXXZ @ 57 NONAME ; void CIMPSConnUiPresEventNotifier::StartL(void)
	?StartServiceL@CIMPSConnectionUiAgent@@QAEHW4TIMPSConnectionUiAgentService@@@Z @ 58 NONAME ; int CIMPSConnectionUiAgent::StartServiceL(enum TIMPSConnectionUiAgentService)
	?Stop@CIMPSConnUiConnectionModeNotifier@@UAEXXZ @ 59 NONAME ; void CIMPSConnUiConnectionModeNotifier::Stop(void)
	?Stop@CIMPSConnUiConnectionSettingsNotifier@@UAEXXZ @ 60 NONAME ; void CIMPSConnUiConnectionSettingsNotifier::Stop(void)
	?Stop@CIMPSConnUiPresEventNotifier@@UAEXXZ @ 61 NONAME ; void CIMPSConnUiPresEventNotifier::Stop(void)
	?StopAllServices@CIMPSConnectionUiAgent@@QAEXXZ @ 62 NONAME ; void CIMPSConnectionUiAgent::StopAllServices(void)
	?StopService@CIMPSConnectionUiAgent@@QAEHW4TIMPSConnectionUiAgentService@@@Z @ 63 NONAME ; int CIMPSConnectionUiAgent::StopService(enum TIMPSConnectionUiAgentService)
	?UseResourceFileL@CIMPSConnectionUiAgent@@QAEXABVTDesC16@@@Z @ 64 NONAME ; void CIMPSConnectionUiAgent::UseResourceFileL(class TDesC16 const &)
	?ValidWVLoginIAPL@IMPSPresenceLoginDetailValidator@@SAHK@Z @ 65 NONAME ; int IMPSPresenceLoginDetailValidator::ValidWVLoginIAPL(unsigned long)
	?ValidWVLoginIdL@IMPSPresenceLoginDetailValidator@@SAHABVTDesC16@@@Z @ 66 NONAME ; int IMPSPresenceLoginDetailValidator::ValidWVLoginIdL(class TDesC16 const &)

